| est_natmort | R Documentation |
Several methods may be used to estimate instantaneous (M) and conditional natural mortality (cm) from other types of data, especially those saved in the life history parameters vector/list from makeLH.
est_natmort(lhparms = NULL, method = "rFAMS", incl.avg = FALSE, ...)
lhparms |
A named vector or string returned by |
method |
A string that indicates what methods to use to estimate M (see |
incl.avg |
A logical that indicates whether the average cm should be computed from the estimated M of all methods. |
... |
Option arguments for parameter values required by methods using parameters other than those in |
The default methods to use are all of those listed in Mmethods that use some of the life history parameters required by makeLH. These methods are not all equally useful or robust, so the user may want to select a subset of them for use after learning more about them. See references in metaM.
Other methods that require parameters other than those required by makeLH can be used by providing the name of the method in method and the required parameters as arguments, as defined in metaM. See metaM for more details and the examples below for an example.
A data.frame with the following items:
method: The name for the method within the function (as given in method).
M: The estimated instantaneous natural mortality rate (from metaM)
cm: The estimated conditional natural mortality rate (computed directly from M).
givens: A string that contains the input values required by the method to estimate M.
Derek Ogle
# An example lhparm as would be returned from makeLH
tmp <- list(N0=100,tmax=15,Linf=500,K=0.3,t0=-0.5,LWalpha=-5.16,LWbeta=3.1)
# All methods in metaM() that use those life history parameters
est_natmort(tmp)
# Same but including the average in the last row
est_natmort(tmp,incl.avg=TRUE)
# Selecting just one method
est_natmort(tmp,method="HoenigNLS")
# Selecting several methods
est_natmort(tmp,method=c("HoenigNLS","HoenigO","HoenigO2","HoenigLM"))
# A method that uses a parameter not usually in lhparms
est_natmort(tmp,method="QuinnDeriso",PS=0.05)
# Selecting all Hoenig methods using Mmethods from FSA
est_natmort(tmp,method=FSA::Mmethods("Hoenig"))
# Over-riding the Linf param in parameters list, but others from tmp
est_natmort(tmp,method="PaulyLNoT") # Linf from tmp
est_natmort(tmp,Linf=1000/10,method="PaulyLNoT") # Linf from Linf= arg
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.